# Xappt_QT

Qt/PyQt5 interface plugin for [Xappt](https://github.com/cmontesano/xappt.git)


## Examples

Xappt_QT ships with a few example plugins that you can dissect. To load these plugins set an environment variable named XAPPT_LOAD_EXAMPLE_TOOLS to "1" before loading Xappt_QT.

```bash
$ export XAPPT_LOAD_EXAMPLE_TOOLS=1
```

These examples can be found in `xappt_qt.plugins.tools.examples`.
